# Generated by ariadne-codegen on 2024-01-31 14:49
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SlimSubscriptionFragment


class TransferSubscription(BaseModel):
    transfer_subscription: "TransferSubscriptionTransferSubscription" = Field(
        alias="transferSubscription"
    )


class TransferSubscriptionTransferSubscription(SlimSubscriptionFragment):
    pass


TransferSubscription.update_forward_refs()
TransferSubscriptionTransferSubscription.update_forward_refs()
