# Generated by ariadne-codegen on 2024-01-31 14:49
# Source: operations.graphql

from .base_model import BaseModel
from .fragments import EntitlementFragment


class GetEntitlement(BaseModel):
    entitlement: "GetEntitlementEntitlement"


class GetEntitlementEntitlement(EntitlementFragment):
    pass


GetEntitlement.update_forward_refs()
GetEntitlementEntitlement.update_forward_refs()
