# Generated by ariadne-codegen on 2024-01-31 14:49
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SlimCustomerFragment


class UnarchiveCustomer(BaseModel):
    unarchive_customer: "UnarchiveCustomerUnarchiveCustomer" = Field(
        alias="unarchiveCustomer"
    )


class UnarchiveCustomerUnarchiveCustomer(SlimCustomerFragment):
    pass


UnarchiveCustomer.update_forward_refs()
UnarchiveCustomerUnarchiveCustomer.update_forward_refs()
