# Generated by ariadne-codegen on 2024-01-31 14:49
# Source: operations.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .fragments import CustomerStatisticsFragment


class GetCustomerStatistics(BaseModel):
    get_customer_by_ref_id: Optional["GetCustomerStatisticsGetCustomerByRefId"] = Field(
        alias="getCustomerByRefId"
    )


class GetCustomerStatisticsGetCustomerByRefId(CustomerStatisticsFragment):
    pass


GetCustomerStatistics.update_forward_refs()
GetCustomerStatisticsGetCustomerByRefId.update_forward_refs()
