# Generated by ariadne-codegen on 2024-01-31 14:49
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel


class CancelSubscriptionUpdates(BaseModel):
    cancel_schedule: str = Field(alias="cancelSchedule")


CancelSubscriptionUpdates.update_forward_refs()
