# Generated by ariadne-codegen on 2024-01-31 14:49
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import ProvisionSubscriptionFragment


class ProvisionSubscription(BaseModel):
    provision_subscription: "ProvisionSubscriptionProvisionSubscription" = Field(
        alias="provisionSubscription"
    )


class ProvisionSubscriptionProvisionSubscription(ProvisionSubscriptionFragment):
    pass


ProvisionSubscription.update_forward_refs()
ProvisionSubscriptionProvisionSubscription.update_forward_refs()
